@@ -1,10 +1,9 @@
 package Catalyst::Plugin::ConfigLoader::MultiState;
-use parent qw/Class::Accessor::Grouped/;
 use strict;
 use Carp();
 use Storable();
 
-our $VERSION = 0.08;
+our $VERSION = 0.10;
 
 =head1 NAME
 
@@ -492,7 +491,7 @@ You may distribute this code under the same terms as Perl itself.
 
 =cut
 
-__PACKAGE__->mk_group_accessors(inherited => qw/cfg dev/);
+use CAIXS inherited => [qw/cfg dev/];
 
 sub setup {
     my $class = shift;
